@@ -1,4 +1,4 @@
-# Copyright (C) 2004-2012 by Barry A. Warsaw
+# Copyright (C) 2004-2013 by Barry A. Warsaw
 #
 # This file is part of flufl.enum
 #
@@ -21,12 +21,12 @@ from __future__ import absolute_import, print_function, unicode_literals
 __metaclass__ = type
 __all__ = [
     'Enum',
+    'IntEnum',
     '__version__',
-    'make_enum',
+    'make',
     ]
 
 
-__version__ = '3.3.2'
+__version__ = '4.0'
 
-
-from ._enum import Enum, make, make_enum
+from ._enum import Enum, IntEnum, make
